'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var lezerDot = require('lezer-dot');
var language = require('@codemirror/language');
var highlight = require('@codemirror/highlight');

const dotLanguage = language.LRLanguage.define({
    parser: lezerDot.parser.configure({
        props: [
            language.indentNodeProp.add({
                "Graph Subgraph": cx => cx.baseIndent + cx.unit,
            }),
            highlight.styleTags({
                "graph digraph node edge strict subgraph": highlight.tags.keyword,
                Quoted: highlight.tags.string,
                Numeral: highlight.tags.number,
                ID: highlight.tags.variableName,
                "edgeop =": highlight.tags.operator,
                "[ ]": highlight.tags.squareBracket,
                "{ }": highlight.tags.brace,
                ", ;": highlight.tags.separator,
                "LineComment SharpComment": highlight.tags.lineComment,
                BlockComment: highlight.tags.blockComment,
            }),
        ],
    }),
    languageData: {
        closeBrackets: { brackets: ["[", "{", '"'] },
        commentTokens: { line: "//", block: { open: "/*", close: "*/" } },
        indentOnInput: /^\s*(?:\{|\})$/,
    },
});
function dot(_config = {}) {
    return new language.LanguageSupport(dotLanguage, dotLanguage.data.of({}));
}

exports.dot = dot;
exports.dotLanguage = dotLanguage;
