import { parser } from 'lezer-dot';
import { LRLanguage, indentNodeProp, LanguageSupport } from '@codemirror/language';
import { styleTags, tags } from '@codemirror/highlight';

const dotLanguage = /*@__PURE__*/LRLanguage.define({
    parser: /*@__PURE__*/parser.configure({
        props: [
            /*@__PURE__*/indentNodeProp.add({
                "Graph Subgraph": cx => cx.baseIndent + cx.unit,
            }),
            /*@__PURE__*/styleTags({
                "graph digraph node edge strict subgraph": tags.keyword,
                Quoted: tags.string,
                Numeral: tags.number,
                ID: tags.variableName,
                "edgeop =": tags.operator,
                "[ ]": tags.squareBracket,
                "{ }": tags.brace,
                ", ;": tags.separator,
                "LineComment SharpComment": tags.lineComment,
                BlockComment: tags.blockComment,
            }),
        ],
    }),
    languageData: {
        closeBrackets: { brackets: ["[", "{", '"'] },
        commentTokens: { line: "//", block: { open: "/*", close: "*/" } },
        indentOnInput: /^\s*(?:\{|\})$/,
    },
});
function dot(_config = {}) {
    return new LanguageSupport(dotLanguage, dotLanguage.data.of({}));
}

export { dot, dotLanguage };
